package com.ruoyi.k3cloud.business.prodOrder.service;

import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.kingdee.bos.webapi.sdk.K3CloudApi;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.k3cloud.business.prodOrder.constants.K3ProdMainField;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * 金蝶生产订单Service
 * @author wjh
 * 2024/10/30
 */
@Service
@Slf4j
public class K3ProdOrderService {

    @Autowired
    private K3CloudApi api;

    // 表单ID
    public static final String FORM_ID = "PRD_MO";

    // 字段列表
    public static final List<String> MAIN_FIELD_KEYS = Arrays.asList(
            K3ProdMainField.FID,
            K3ProdMainField.F_BILL_NO,
            K3ProdMainField.F_DOCUMENT_STATUS,
            K3ProdMainField.F_CREATE_DATE,
            K3ProdMainField.F_DESCRIPTION,
            K3ProdMainField.F_BILL_TYPE,
            K3ProdMainField.F_WORK_SHOP_ID0,
            K3ProdMainField.F_PRD_ORG_ID,
            K3ProdMainField.F_DATE,
            K3ProdMainField.F_IS_REWORK
    );

    /**
     * 查询列表
     */
    public List<JSONArray> selectList(int startRow, int limit) {
        try {
            JSONObject params = new JSONObject();
            params.put("FormId", FORM_ID);
            params.put("FieldKeys", String.join(",", MAIN_FIELD_KEYS));
            params.put("FilterString", "");
            params.put("OrderString", "");
            params.put("TopRowCount", 0);
            params.put("StartRow", startRow);
            params.put("Limit", limit);
            params.put("SubSystemId", "");
            String res = api.executeBillQueryJson(JSONObject.toJSONString(params));
            if (StringUtils.isBlank(res)) {
                return Collections.emptyList();
            }
            return JSONArray.parseArray(res, JSONArray.class);
        } catch (Exception e) {
            log.error("获取云星空生产订单失败{}", e.getMessage());
            throw new ServiceException("获取云星空生产订单失败");
        }
    }
}
