package com.ruoyi.web.yh.prodOrder.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.yh.prodOrder.domain.ProdOrder;
import com.ruoyi.web.yh.prodOrder.domain.ProdOrderVO;
import com.ruoyi.web.yh.prodOrder.domain.ProdOrderQuery;
import com.ruoyi.web.yh.prodOrder.service.ProdOrderService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 生产订单Controller
 *
 * @author ruoyi
 * @date 2024-10-29
 */
@RestController
@RequestMapping("/yh/prodOrder")
public class ProdOrderController extends BaseController
{
    @Autowired
    private ProdOrderService prodOrderService;

    /**
     * 查询生产订单列表
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdOrderQuery query)
    {
        startPage();
        startOrderBy();
        List<ProdOrderVO> list = prodOrderService.selectProdOrderList(query);
        return getDataTable(list);
    }

    /**
     * 导出生产订单列表
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:export')")
    @Log(title = "导出生产订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdOrderQuery query)
    {
        List<ProdOrderVO> list = prodOrderService.selectProdOrderList(query);
        ExcelUtil<ProdOrderVO> util = new ExcelUtil<ProdOrderVO>(ProdOrderVO.class);
        util.exportExcel(response, list, "生产订单数据");
    }

    /**
     * 获取生产订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(prodOrderService.selectProdOrderById(id));
    }

    /**
     * 新增生产订单
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:add')")
    @Log(title = "新增生产订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdOrder prodOrder)
    {
        return toAjax(prodOrderService.insertProdOrder(prodOrder));
    }

    /**
     * 修改生产订单
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:edit')")
    @Log(title = "修改生产订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdOrder prodOrder)
    {
        return toAjax(prodOrderService.updateProdOrder(prodOrder));
    }

    /**
     * 删除生产订单
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:remove')")
    @Log(title = "删除生产订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(prodOrderService.deleteProdOrderByIds(ids));
    }

    @PreAuthorize("@ss.hasPermi('yh:productOrder:sync')")
    @Log(title = "同步生产订单", businessType = BusinessType.SYNC)
    @PutMapping("/sync")
    public AjaxResult sync() {
        return success(prodOrderService.sync());
    }
}
