package com.ruoyi.web.yh.prodOrder.service.impl;

import com.alibaba.fastjson2.JSONArray;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.k3cloud.business.prodOrder.constants.K3ProdMainField;
import com.ruoyi.web.yh.prodOrder.domain.ProdOrder;
import com.ruoyi.web.yh.prodOrder.service.ProdOrderConverter;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * @author wjh
 * 2024/10/30
 */
@Service
public class ProdOrderConverterImpl implements ProdOrderConverter {
    /**
     * 将ERP数据转为PO列表
     *
     * @param headers 表头列表
     * @param erpList ERP数据列表
     */
    @Override
    public List<ProdOrder> toPoByErpList(List<String> headers, List<JSONArray> erpList) {
        if (CollectionUtils.isEmpty(headers) || CollectionUtils.isEmpty(erpList)) {
            return Collections.emptyList();
        }

        // 创建erpList大小的对象列表
        List<ProdOrder> result = new ArrayList<>(erpList.size());

        for (JSONArray row : erpList) {
            ProdOrder po = new ProdOrder();
            for (int i = 0; i < headers.size(); i++) {
                String header = headers.get(i);
                switch(header) {
                    case K3ProdMainField.FID:
                        po.setErpId(row.getString(i));
                        break;
                    case K3ProdMainField.F_BILL_NO:
                        po.setBillNo(row.getString(i));
                        break;
                    case K3ProdMainField.F_BILL_TYPE:
                        po.setType(row.getString(i));
                        break;
                    case K3ProdMainField.F_DATE:
                        po.setBillDate(DateUtils.toLocalDate(row.getDate(i)));
                        break;
                    case K3ProdMainField.F_DOCUMENT_STATUS:
                        po.setStatus(row.getString(i));
                        break;
                    default: break;
                }
            }
            result.add(po);
        }

        return result;
    }
}
