package com.ruoyi.web.yh.report.controller;

import java.util.Collections;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.web.yh.report.domain.bo.ReportBO;
import com.ruoyi.web.yh.report.domain.dto.ReportVerifyDTO;
import com.ruoyi.web.yh.report.service.ReportAssembler;
import com.ruoyi.web.yh.report.service.ReportConverter;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.yh.report.domain.Report;
import com.ruoyi.web.yh.report.domain.ReportVO;
import com.ruoyi.web.yh.report.domain.ReportQuery;
import com.ruoyi.web.yh.report.service.ReportService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 报表Controller
 *
 * @author ruoyi
 * @date 2024-10-18
 */
@RestController
@RequestMapping("/yh/report")
public class ReportController extends BaseController
{
    @Autowired
    private ReportService reportService;

    @Autowired
    private ReportConverter reportConverter;

    @Autowired
    private ReportAssembler reportAssembler;

    /**
     * 查询报表列表
     */
    @PreAuthorize("@ss.hasAnyPermi({'yh:report:list', 'yh:report:groupList'})")
    @GetMapping("/list")
    public TableDataInfo list(ReportQuery query)
    {
        startPage();
        startOrderBy();
        List<ReportVO> list = reportService.selectReportList(query);
        return getDataTable(list);
    }

    /**
     * 导出报表列表
     */
    @PreAuthorize("@ss.hasPermi('yh:report:export')")
    @Log(title = "车间报表导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ReportQuery query)
    {
        List<ReportVO> list = reportService.selectReportList(query);
        ExcelUtil<ReportVO> util = new ExcelUtil<ReportVO>(ReportVO.class);
        util.exportExcel(response, list, "报表数据");
    }

    /**
     * 获取报表详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:report:query')")
    @GetMapping(value = "/{reportId}")
    public AjaxResult getInfo(@PathVariable("reportId") Long reportId)
    {
        ReportVO report = reportService.selectReportByReportId(reportId);
        List<ReportVO> list = Collections.singletonList(report);
        reportAssembler.assembleProductList(list, true);  // 拼接产量明细
        return success(report);
    }

    /**
     * 新增报表
     */
    @PreAuthorize("@ss.hasPermi('yh:report:add')")
    @Log(title = "车间报表新增", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) ReportVO data)
    {
        ReportBO bo = reportConverter.toBoByCreate(data);
        return toAjax(reportService.addReport(bo));
    }

    /**
     * 修改报表
     */
    @PreAuthorize("@ss.hasPermi('yh:report:edit')")
    @Log(title = "车间报表修改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) ReportVO data) {
        ReportBO bo = reportConverter.toBoByUpdate(data);
        return toAjax(reportService.editReport(bo));
    }

    /**
     * 删除报表
     */
    @PreAuthorize("@ss.hasPermi('yh:report:remove')")
    @Log(title = "车间报表删除", businessType = BusinessType.DELETE)
	@DeleteMapping("/{reportIds}")
    public AjaxResult remove(@PathVariable Long[] reportIds)
    {
        return toAjax(reportService.deleteReportByReportIds(reportIds));
    }

    @PreAuthorize("@ss.hasPermi('yh:report:verify')")
    @Log(title = "车间报表审核", businessType = BusinessType.VERIFY)
	@PutMapping("/verify")
    public AjaxResult verify(@RequestBody @Validated ReportVerifyDTO dto) {
        return toAjax(reportService.verify(dto, getUserId()));
    }
}
